@@ -17,7 +17,6 @@ import (
 	"github.com/snyk/driftctl/pkg/config"
 	"github.com/snyk/driftctl/pkg/version"
 	"github.com/snyk/driftctl/sentry"
-	"github.com/spf13/viper"
 )
 
 func init() {
@@ -35,7 +34,7 @@ func run() int {
 	logger.Init()
 	build := build.Build{}
 	// Check whether driftCTL is run under Snyk CLI
-	isSnyk := viper.GetBool("IS_SNYK")
+	isSnyk := config.IsSnyk()
 	logrus.WithFields(logrus.Fields{
 		"isRelease":               fmt.Sprintf("%t", build.IsRelease()),
 		"isUsageReportingEnabled": fmt.Sprintf("%t", build.IsUsageReportingEnabled()),
